import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart' as con;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

class CustomChart extends StatefulWidget {
  final Chartparms chartparms;

  CustomChart({this.chartparms});

  @override
  _CustomChartState createState() => _CustomChartState();
}

class _CustomChartState extends State<CustomChart> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //init();
  }

  Widget mychart = Container();

  @override
  Widget build(BuildContext context) {
    if (widget.chartparms.ChartType == 'PieChart') {
      setState(() {
        mychart = _createPieChart(widget.chartparms.series,
            widget.chartparms.arcValue, widget.chartparms.labelFontSize);
      });
    }
    if (widget.chartparms.ChartType == 'BarChart') {
      setState(() {
        mychart = createBarChart(widget.chartparms.series);
      });
    }
    if (widget.chartparms.ChartType == 'StackedBarChart') {
      setState(() {
        mychart = createStackBarChart(widget.chartparms.series);
      });
    }
    if (widget.chartparms.ChartType == '100Percent StackChart') {
      setState(() {
        mychart = create100PercentStackChart(widget.chartparms.series);
      });
    }
    if (widget.chartparms.ChartType == 'CategoryBarChart') {
      setState(() {
        mychart = createCategoryBarChart(widget.chartparms.series);
      });
    }
    if (widget.chartparms.ChartType == 'LineChart') {
      setState(() {
        mychart = _createLineChart(widget.chartparms.series);
      });
    }
    if (widget.chartparms.ChartType == 'HorizontalBarChart') {
      setState(() {
        mychart = Container(
            child: _createHorzontalBarChart(widget.chartparms.series));
      });
    }
    if (widget.chartparms.ChartType == 'BarLineChart') {
      setState(() {
        mychart = _OrdinalComboBarLineChart(widget.chartparms.series);
      });
    }
    return Container(
      child: mychart,
    );
  }

  Widget _createPieChart(List<charts.Series<dynamic, dynamic>> objSeries,
      int arcValue, int labelFontSize) {
    charts.PieChart mPieChart;

    mPieChart = new charts.PieChart(
      objSeries,
      animate: true,
      animationDuration: Duration(seconds: 2),
      defaultRenderer: new charts.ArcRendererConfig(
          arcWidth: (arcValue != null) ? arcValue : 5,
          arcRendererDecorators: [
            new charts.ArcLabelDecorator(
              outsideLabelStyleSpec: new charts.TextStyleSpec(
                  fontSize: (labelFontSize != null) ? labelFontSize : 10),
              labelPosition: charts.ArcLabelPosition.auto,
            )
          ]),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 14.0, bottom: 4.0, top: 15, left: 15),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
    );
    return mPieChart;
  }

  Widget _createHorzontalBarChart(
      List<charts.Series<dynamic, dynamic>> objSeries) {
    
    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(
      objSeries,
      animate: true,
      vertical: false,
      animationDuration: Duration(seconds: con.intTwo),
      domainAxis: new charts.OrdinalAxisSpec(
          showAxisLine: false,
          renderSpec: new charts.SmallTickRendererSpec(
              labelRotation: 0,
              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16,
                  fontFamily: 'Arial', // size in Pts.
                  color: charts.MaterialPalette.black),
              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.black))),
      primaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      secondaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 10, bottom: 4.0, top: 25, left: 10),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
      defaultRenderer: new charts.BarRendererConfig(
        cornerStrategy: charts.ConstCornerStrategy(
            (widget.chartparms.barChartRadius != null)
                ? widget.chartparms.barChartRadius
                : 5),
      ),
    );

    return mBarChart;
  }

  Widget _createLineChart(List<charts.Series<dynamic, dynamic>> objSeries) {
    charts.LineChart mLineChart;
    mLineChart = charts.LineChart(objSeries,
        animationDuration: Duration(seconds: 5),
        animate: true,
        /*domainAxis: new charts.OrdinalAxisSpec(
            showAxisLine: false,
            renderSpec: new charts.SmallTickRendererSpec(
                labelRotation: 0,
                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16,
                    fontFamily: 'Arial',// size in Pts.
                    color: charts.MaterialPalette.black),
                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.black))),*/
        primaryMeasureAxis: new charts.NumericAxisSpec(
            renderSpec: new charts.GridlineRendererSpec(

                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16, // size in Pts.
                    fontFamily: 'Arial',
                    color: charts.MaterialPalette.black),

                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.transparent))),
        secondaryMeasureAxis: new charts.NumericAxisSpec(
            renderSpec: new charts.GridlineRendererSpec(

                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16, // size in Pts.
                    fontFamily: 'Arial',
                    color: charts.MaterialPalette.black),

                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.transparent))),
        behaviors: [
          new charts.DatumLegend(
            position: charts.BehaviorPosition.bottom,
            outsideJustification: charts.OutsideJustification.middleDrawArea,
            horizontalFirst: false,
            desiredMaxRows: 2,
            cellPadding: new EdgeInsets.only(
                right: 14.0, bottom: 4.0, top: 15, left: 15),
            entryTextStyle: charts.TextStyleSpec(
                //color: charts.Color(r: 127, g: 63, b: 200),
                fontFamily: 'Arial',
                fontSize: 16),
          )
        ],
        defaultRenderer: new charts.LineRendererConfig(
            includeArea: true, stacked: false, includePoints: true));
    return mLineChart;
  }

  Widget _OrdinalComboBarLineChart(
      List<charts.Series<dynamic, dynamic>> objSeries) {
    return new charts.OrdinalComboChart(objSeries,
        animate: true,
        domainAxis: new charts.OrdinalAxisSpec(
            showAxisLine: false,
            renderSpec: new charts.SmallTickRendererSpec(
                labelRotation: 45,
                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16,
                    fontFamily: 'Arial', // size in Pts.
                    color: charts.MaterialPalette.black),
                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.black))),
        primaryMeasureAxis: new charts.NumericAxisSpec(
            renderSpec: new charts.GridlineRendererSpec(

                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16, // size in Pts.
                    fontFamily: 'Arial',
                    color: charts.MaterialPalette.black),

                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.transparent))),
        secondaryMeasureAxis: new charts.NumericAxisSpec(
            renderSpec: new charts.GridlineRendererSpec(

                // Tick and Label styling here.
                labelStyle: new charts.TextStyleSpec(
                    fontSize: 16, // size in Pts.
                    fontFamily: 'Arial',
                    color: charts.MaterialPalette.black),

                // Change the line colors to match text color.
                lineStyle: new charts.LineStyleSpec(
                    color: charts.MaterialPalette.transparent))),
        behaviors: [
          new charts.DatumLegend(
            position: charts.BehaviorPosition.bottom,
            outsideJustification: charts.OutsideJustification.middleDrawArea,
            horizontalFirst: false,
            desiredMaxRows: 2,
            cellPadding: new EdgeInsets.only(
                right: 14.0, bottom: 4.0, top: 15, left: 15),
            entryTextStyle: charts.TextStyleSpec(
                //color: charts.Color(r: 127, g: 63, b: 200),
                fontFamily: 'Arial',
                fontSize: 16),
          )
        ],
        animationDuration: Duration(seconds: 2),
        // Configure the default renderer as a bar renderer.
        defaultRenderer: new charts.BarRendererConfig(
          groupingType: charts.BarGroupingType.grouped,
          cornerStrategy: charts.ConstCornerStrategy(
              (widget.chartparms.barChartRadius != null)
                  ? widget.chartparms.barChartRadius
                  : 5),
        ),
        // Custom renderer configuration for the line series. This will be used for
        // any series that does not define a rendererIdKey.
        customSeriesRenderers: [
          new charts.LineRendererConfig(
              // ID used to link series to this renderer.
              customRendererId: 'customLine')
        ]);
  }

  Widget createBarChart(List<charts.Series<dynamic, dynamic>> objSeries) {
    //print("Series "+widget.chartparms.series.toString());

    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(
      objSeries,
      animate: true,
      vertical: true,
      animationDuration: Duration(seconds: con.intTwo),
      domainAxis: new charts.OrdinalAxisSpec(
          showAxisLine: false,
          renderSpec: new charts.SmallTickRendererSpec(
              labelRotation: 45,
              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16,
                  fontFamily: 'Arial', // size in Pts.
                  color: charts.MaterialPalette.black),
              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.black))),
      primaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      secondaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 14.0, bottom: 4.0, top: 15, left: 15),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
      defaultRenderer: new charts.BarRendererConfig(
        cornerStrategy: charts.ConstCornerStrategy(5),
      ),
    );

    return mBarChart;
  }

  Widget createStackBarChart(List<charts.Series<dynamic, dynamic>> objSeries) {
    //print("Series "+widget.chartparms.series.toString());

    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(
      objSeries,
      animate: true,
      vertical: true,
      barGroupingType: charts.BarGroupingType.stacked,
      animationDuration: Duration(seconds: con.intTwo),
      domainAxis: new charts.OrdinalAxisSpec(
          showAxisLine: false,
          renderSpec: new charts.SmallTickRendererSpec(
              labelRotation: 45,
              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16,
                  fontFamily: 'Arial', // size in Pts.
                  color: charts.MaterialPalette.black),
              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.black))),
      //100 percent
      /* primaryMeasureAxis: new charts.PercentAxisSpec(
        renderSpec: new charts.GridlineRendererSpec(
            labelStyle: new charts.TextStyleSpec(
                fontSize: 16, // size in Pts.
                fontFamily: 'Arial',
                color: charts.MaterialPalette.black),

            // Change the line colors to match text color.
            lineStyle: new charts.LineStyleSpec(
                color: charts.MaterialPalette.transparent)
        )
    ),*/
      primaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),

      secondaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      behaviors: [
        //100 percent
        /*  new charts.PercentInjector(
          totalType: charts.PercentInjectorTotalType.domain
      ),*/
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 14.0, bottom: 4.0, top: 15, left: 15),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
    );

    return mBarChart;
  }

  Widget create100PercentStackChart(
      List<charts.Series<dynamic, dynamic>> objSeries) {
    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(
      objSeries,
      animate: true,
      vertical: true,
      barGroupingType: charts.BarGroupingType.stacked,
      animationDuration: Duration(seconds: con.intTwo),
      domainAxis: new charts.OrdinalAxisSpec(
          showAxisLine: false,
          renderSpec: new charts.SmallTickRendererSpec(
              labelRotation: 45,
              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16,
                  fontFamily: 'Arial', // size in Pts.
                  color: charts.MaterialPalette.black),
              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.black))),
      //100 percent
      primaryMeasureAxis: new charts.PercentAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      secondaryMeasureAxis: new charts.PercentAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      behaviors: [
        //100 percent
        new charts.PercentInjector(
            totalType: charts.PercentInjectorTotalType.domain),
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 14.0, bottom: 4.0, top: 15, left: 15),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
    );

    return mBarChart;
  }

  Widget createCategoryBarChart(
      List<charts.Series<dynamic, dynamic>> objSeries) {
    //print("Series "+widget.chartparms.series.toString());

    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(
      objSeries,
      animate: true,
      vertical: true,
      //barGroupingType: charts.BarGroupingType.stacked,
      animationDuration: Duration(seconds: con.intTwo),
      domainAxis: new charts.OrdinalAxisSpec(
          showAxisLine: false,
          renderSpec: new charts.SmallTickRendererSpec(
              labelRotation: 45,
              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16,
                  fontFamily: 'Arial', // size in Pts.
                  color: charts.MaterialPalette.black),
              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.black))),
      primaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      secondaryMeasureAxis: new charts.NumericAxisSpec(
          renderSpec: new charts.GridlineRendererSpec(

              // Tick and Label styling here.
              labelStyle: new charts.TextStyleSpec(
                  fontSize: 16, // size in Pts.
                  fontFamily: 'Arial',
                  color: charts.MaterialPalette.black),

              // Change the line colors to match text color.
              lineStyle: new charts.LineStyleSpec(
                  color: charts.MaterialPalette.transparent))),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: 2,
          cellPadding:
              new EdgeInsets.only(right: 14.0, bottom: 4.0, top: 15, left: 15),
          entryTextStyle: charts.TextStyleSpec(
              //color: charts.Color(r: 127, g: 63, b: 200),
              fontFamily: 'Arial',
              fontSize: 16),
        )
      ],
    );

    return mBarChart;
  }
}
